Learn R Programming

dtgiw (version 1.0.0)

dDTGIW: The probability mass function (PMF) for Discrete Transmuted Generalized Inverse Weibull (DTGIW) distribution.

Description

This function calculated the PMF of the DTGIW distribution.

Usage

dDTGIW(x, alpha, beta, lambda, theta, log = FALSE)

Arguments

x

vector of quantiles.

alpha

shape parameter#1.

beta

scale parameter.

lambda

shape pameter#2.

theta

the transmuted parameter.

log

logical(TRUE or FALSE); if log=FALSE, then return the PMF; if log=TRUE, then return the natural logarithms of the PMF.

Value

the PMF of DTGIW distribution

Details

The PMF of the DTGIW distribution is shown in Theorem 1 based on the research paper in references.

References

Atchanut Rattanalertnusorn and Sirinapa Aryuyuen (2021). The zero-truncated discrete transmuted generalized inverse Weibull distribution and its applications, Songklanakarin Journal of Science and Technology (SJST), Volume 43 No.4 (July - August 2021), pp. 1140 - 1151. DOI: 10.14456/sjst-psu.2021.149

Examples

Run this code
# NOT RUN {
x <- c(0:10)
dDTGIW(x,3.45,0.7,1.05,0)
# }

Run the code above in your browser using DataLab