Learn R Programming

dtgiw (version 1.0.0)

loglikeDTGIW: Negative Log-Likelihood value of DTGIW distribution.

Description

The function for calculating negative log-likelihood value of DTGIW distribution.

Usage

loglikeDTGIW(x, alpha, beta, lambda, theta)

Arguments

x

a vector of quantile

alpha

shape parameter#1

beta

scale parameter

lambda

shape pameter#2

theta

the transmuted parameter

Value

the negative log-likelihood value of DTGIW distribution

References

Atchanut Rattanalertnusorn and Sirinapa Aryuyuen (2021). The zero-truncated discrete transmuted generalized inverse Weibull distribution and its applications, Songklanakarin Journal of Science and Technology (SJST), Volume 43 No.4 (July - August 2021), pp. 1140 - 1151 <DOI: 10.14456/sjst-psu.2021.149>.

Examples

Run this code
# NOT RUN {
x <- rDTGIW(n=20,3.45,0.7,1.05,0)
loglikeDTGIW(x,3.45,0.7,1.05,0)
# }

Run the code above in your browser using DataLab