Learn R Programming

dtgiw (version 1.0.0)

qDTGIW: The quantile function for Discrete Transmuted Generalized Inverse Weibull (DTGIW) distribution.

Description

This function calculated the quantile values of the DTGIW distribution.

Usage

qDTGIW(p, alpha, beta, lambda, theta, lower.tail = TRUE, log.p = FALSE)

Arguments

p

vector of probabilities

alpha

shape parameter#1.

beta

scale parameter.

lambda

shape pameter#2.

theta

the transmuted parameter.

lower.tail

logical; if TRUE (default), probabilities are Prob of X less than or equal to x. Otherwise, Prob of X greater than x.

log.p

logical(TRUE or FALSE); if log.p=FALSE, then return the cdf; if log.p=TRUE, then return the natural logarithms of the cdf.

Value

the quantile values of DTGIW distribution

Details

The R script calculated the quantile values of the DTGIW distribution is shown based on the research paper in references.

References

Atchanut Rattanalertnusorn and Sirinapa Aryuyuen (2021). The zero-truncated discrete transmuted generalized inverse Weibull distribution and its applications, Songklanakarin Journal of Science and Technology (SJST), Volume 43 No.4 (July - August 2021), pp. 1140 - 1151. DOI: 10.14456/sjst-psu.2021.149.

Examples

Run this code
# NOT RUN {
x <- c(0:10)
p<- pDTGIW(x,3.45,0.7,1.05,0)
qDTGIW(p,3.45,0.7,1.05,0)

# }

Run the code above in your browser using DataLab