rDTGIW: The random generating function for Discrete Transmuted Generalized Inverse Weibull(DTGIW) distribution.
Description
This function generates random numbers for the DTGIW distribution.
Usage
rDTGIW(n, alpha, beta, lambda, theta)
Arguments
n
number of observations. If length(n) > 1, the length is taken to be the number required.
alpha
shape parameter#1.
beta
scale parameter.
lambda
shape pameter#2.
theta
the transmuted parameter.
Value
the n random number of DTGIW distribution.
Details
The R script generates the n random values of the DTGIW distribution is shown based on the research paper in references.
References
Atchanut Rattanalertnusorn and Sirinapa Aryuyuen (2021).
The zero-truncated discrete transmuted generalized inverse Weibull distribution and its applications,
Songklanakarin Journal of Science and Technology (SJST), Volume 43 No.4 (July - August 2021), pp. 1140 - 1151. DOI: 10.14456/sjst-psu.2021.149.